exceptiontools.ExtraMarkError
=============================

.. abjad-lineage:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError

.. autoclass:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraMarkError.ExtraMarkError.__unicode__
   :noindex:
